@@ -8,8 +8,7 @@
 #' _Baggr_ package provides a suite of models that work with both summary data and full data sets,
 #' to synthesise evidence collected from different groups, contexts or time periods.
 #' The [baggr] command automatically detects the data type and, by default, fits a partial
-#' pooling model (which you may know as
-#' [random effects models](https://stats.stackexchange.com/questions/4700/what-is-the-difference-between-fixed-effect-random-effect-and-mixed-effect-mode))
+#' pooling model (which some users may know as random effects models)
 #' with weakly informative priors by calling [Stan](https://mc-stan.org/) to carry
 #' out Bayesian inference. Modelling of variances or quantiles, standardisation and
 #' transformation of data are also possible.
@@ -22,7 +21,6 @@
 #' For description of models, data types and priors available in the package,
 #' try the built-in vignette (`vignette("baggr")`).
 #'
-#' @docType package
 #' @name baggr-package
 #' @useDynLib baggr, .registration = TRUE
 #' @import methods
@@ -32,4 +30,10 @@
 #'
 #' @references
 #' Stan Development Team (2020). RStan: the R interface to Stan. R package version 2.21.2. https://mc-stan.org
+
+#' @keywords internal
+"_PACKAGE"
+
+## usethis namespace: start
+## usethis namespace: end
 NULL
