@@ -6,6 +6,8 @@
 #' @param data A data frame with columns `a`, `c` and `b`/`n1`, `d`/`n2`.
 #'             (You can also use `ai`, `ci`, `n1i`, `n2i` instead.)
 #' @param group Column name storing group
+#' @param covariates Column names in `data` that contain group-level variables
+#'                   to retain when expanding into individual-level `data.frame`
 #' @param rename_group If `TRUE` (default), this will rename the grouping variable
 #'                     to `"group"`, making it easier to work with [baggr]
 #'
@@ -34,17 +36,19 @@
 #' prepare_ma(df_yusuf, group="trial", effect="logOR")
 #'
 binary_to_individual <- function(data, group = "group",
+                                 covariates = c(),
                                  rename_group = TRUE) {
   df_ind <- data.frame()
-
   if(rename_group)
     group_name <- "group"
   else
     group_name <- group
 
-  if(is.null(data[[group]]))
-    stop("Missing group column")
-
+  if(is.null(data[[group]])){
+    message("Automatically created group labels as they were not defined.")
+    data[[group]] <- paste("Group", 1:nrow(data))
+    # stop("Missing group column")
+  }
   if(!is.null(data[["n1i"]]) && is.null(data[["n1"]])) data[["n1"]] <- data[["n1i"]]
   if(!is.null(data[["n2i"]]) && is.null(data[["n2"]])) data[["n2"]] <- data[["n2i"]]
   if(!is.null(data[["ai"]])  && is.null(data[["a"]]))  data[["a"]] <- data[["ai"]]
@@ -52,7 +56,7 @@ binary_to_individual <- function(data, group = "group",
 
 
   if(is.null(data[["n1"]]) || is.null(data[["n2"]])){
-    data <- data[,c(group, "a", "b", "c", "d")]
+    data <- data[,c(group, "a", "b", "c", "d", covariates)]
     data$n1 <- data$a + data$b
     data$n2 <- data$c + data$d
   }
@@ -63,17 +67,18 @@ binary_to_individual <- function(data, group = "group",
     stop("Non-integer number of events or non-events present in data")
 
   for(i in 1:nrow(data)) {
-    df_ind <-
-      rbind(df_ind,
-            setNames(
-              data.frame(
-                data[[group]][i],
-                c(rep(1, data$n1[i]), rep(0, data$n2[i])),
-                c(rep(1, data$a[i]),  rep(0, data$n1[i] - data$a[i]),
-                  rep(1, data$c[i]),  rep(0, data$n2[i] - data$c[i]))),
-              c(group_name, "treatment", "outcome")
-            )
-      )
+    current_df <- setNames(
+      data.frame(
+        data[[group]][i],
+        c(rep(1, data$n1[i]), rep(0, data$n2[i])),
+        c(rep(1, data$a[i]),  rep(0, data$n1[i] - data$a[i]),
+          rep(1, data$c[i]),  rep(0, data$n2[i] - data$c[i]))),
+      c(group_name, "treatment", "outcome")
+    )
+    for(cn in covariates)
+      current_df[[cn]] <- data[[cn]][i]
+
+    df_ind <- rbind(df_ind, current_df)
   }
   df_ind
 }
