@@ -6,14 +6,8 @@ check_columns_numeric <- function(data) {
     stop(paste("Column(s)", paste(names(numcols)[numcols], collapse = ","), "are not numeric"))
 }
 
-is_binary <- function(v) {
-  if(is.numeric(v) && all(v %in% c(0,1)))
-    return(TRUE)
-  else
-    return(FALSE)
-}
-
-check_columns <- function(data, outcome, group, treatment, stop.for.na = TRUE)  {
+check_columns_ipd <- function(data, outcome, group, treatment,
+                              stop.for.na = TRUE, trt_binary = FALSE)  {
 
   if(!(is.character(outcome) && is.character(group) && is.character(treatment)))
     stop('Arguments "outcome", "group", "treatment" must be of type "character"')
@@ -29,8 +23,8 @@ check_columns <- function(data, outcome, group, treatment, stop.for.na = TRUE)
   # Are they the correct type
   if(!(is.numeric(data[[outcome]])))
     stop(paste0("Outcome variable in baggr has to be numeric (continuous)"))
-  if(!(is.numeric(data[[treatment]])))
-    stop(paste0("Treatment variable in baggr has to be numeric"))
+  if(!(is.numeric(data[[treatment]]) || is.factor(data[[treatment]])))
+    stop(paste0("Treatment variable in baggr has to be numeric or a factor"))
 
   # NA not allowed
   if(stop.for.na){
@@ -42,14 +36,25 @@ check_columns <- function(data, outcome, group, treatment, stop.for.na = TRUE)
       stop("Some of group values are NA")
   }
 
-  # Treatment has to be dichotomous
-  if(!any((data[[treatment]] == 0) | (data[[treatment]] == 1)))
+  # Treatment has to be dichotomous and include both 0's and 1's
+  if(trt_binary && !is.binary(data[[treatment]])) {
     stop("Treatment column has to have values 0 or 1")
-  if(length(unique(data[[treatment]])) < 2)
+  if(trt_binary && !is.binary(data[[treatment]], both = TRUE))
     stop("Treatment column has to have both 0's and 1's for baggr to work")
-
+  }
 }
 
+is.binary <- function(x, both = FALSE, na.rm = TRUE){
+  if(na.rm)
+    x <- x[!is.na(x)]
+
+  if(!all(x == 0 | x == 1)) return(0)
+  if(both && !any(x == 0))  return(0)
+  if(both && !any(x == 1))  return(0)
+  return(1)
+}
+
+
 check_columns_binary <- function(data, stop=TRUE) {
   if(is.null(data$a) || is.null(data$c) ||
      ((is.null(data$b) || is.null(data$d)) && (is.null(data$n1) || is.null(data$n2)))){
