@@ -151,17 +151,3 @@ test_that("We can set and get baggr theme", {
   expect_is(baggr_theme_replace(), "theme")
   capture_output(baggr_theme_set(ggplot2::theme_bw()))
 })
-
-test_that("silent_messages option", {
-  expect_message(baggr(schools,
-                       control = list(adapt_delta = 0.99999),
-                       refresh = 0
-  )
-  )
-  expect_silent(baggr(schools,
-                      control = list(adapt_delta = 0.99999),
-                      refresh = 0,
-                      silent = TRUE)
-  )
-}
-)
